@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QT3DRENDER_PYTHON_H
@@ -56,6 +20,7 @@
 #include <Qt3DRender/qabstracttexture.h>
 #include <Qt3DRender/qproximityfilter.h>
 #include <Qt3DRender/qlayerfilter.h>
+#include <Qt3DRender/qsubtreeenabler.h>
 #include <Qt3DRender/qpickingsettings.h>
 #include <Qt3DRender/qclearbuffers.h>
 #include <Qt3DRender/qenvironmentlight.h>
@@ -67,6 +32,7 @@
 #include <Qt3DRender/qraycaster.h>
 #include <Qt3DRender/qcullface.h>
 #include <Qt3DRender/qpickevent.h>
+#include <Qt3DRender/qdepthrange.h>
 #include <Qt3DRender/qsceneloader.h>
 #include <Qt3DRender/qgraphicsapifilter.h>
 #include <Qt3DRender/qobjectpicker.h>
@@ -113,6 +79,7 @@
 #include <Qt3DRender/qfilterkey.h>
 #include <Qt3DRender/qtextureimagedata.h>
 #include <Qt3DRender/qrenderstateset.h>
+#include <Qt3DRender/qpickingproxy.h>
 #include <Qt3DRender/qshaderprogram.h>
 #include <Qt3DRender/qwaitfence.h>
 #include <Qt3DRender/qtextureimage.h>
@@ -123,6 +90,7 @@
 #include <Qt3DRender/qrendersettings.h>
 #include <Qt3DRender/qabstractraycaster.h>
 #include <Qt3DRender/qblendequationarguments.h>
+#include <Qt3DRender/qtexturedataupdate.h>
 #include <Qt3DRender/qtechniquefilter.h>
 #include <Qt3DRender/qpointlight.h>
 #include <Qt3DRender/qgeometryrenderer.h>
@@ -138,6 +106,7 @@
 #include <Qt3DRender/qabstracttextureimage.h>
 #include <Qt3DRender/qraycasterhit.h>
 #include <Qt3DRender/qnopicking.h>
+#include <Qt3DRender/qrastermode.h>
 #include <Qt3DRender/qdispatchcompute.h>
 #include <Qt3DRender/qlevelofdetailboundingsphere.h>
 #include <Qt3DRender/qmemorybarrier.h>
@@ -149,21 +118,26 @@
 #include <Qt3DRender/qrenderstate.h>
 #include <Qt3DRender/qeffect.h>
 // Conversion Includes - Primitive Types
-#include <qabstractitemmodel.h>
+#include <QAnyStringView>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -209,135 +183,143 @@ enum : int {
     SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 39,
     SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 42,
     SBK_QT3DRENDER_QCULLFACE_IDX                             = 41,
-    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 44,
-    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 43,
-    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 45,
-    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 46,
-    SBK_QT3DRENDER_QDITHERING_IDX                            = 47,
-    SBK_QT3DRENDER_QEFFECT_IDX                               = 48,
-    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 49,
-    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 50,
-    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 51,
-    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 53,
-    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 52,
-    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 54,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 56,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 55,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 58,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 59,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 57,
-    SBK_QT3DRENDER_QLAYER_IDX                                = 60,
-    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 62,
-    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 61,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 64,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 63,
-    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 65,
-    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 66,
-    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 67,
-    SBK_QT3DRENDER_QMATERIAL_IDX                             = 68,
-    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 70,
+    SBK_QT3DRENDER_QDEPTHRANGE_IDX                           = 43,
+    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 45,
+    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 44,
+    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 46,
+    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 47,
+    SBK_QT3DRENDER_QDITHERING_IDX                            = 48,
+    SBK_QT3DRENDER_QEFFECT_IDX                               = 49,
+    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 50,
+    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 51,
+    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 52,
+    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 54,
+    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 53,
+    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 55,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 57,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 56,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 59,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 60,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 58,
+    SBK_QT3DRENDER_QLAYER_IDX                                = 61,
+    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 63,
+    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 62,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 65,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 64,
+    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 66,
+    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 67,
+    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 68,
+    SBK_QT3DRENDER_QMATERIAL_IDX                             = 69,
+    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 71,
     SBK_QFLAGS_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX       = 1,
-    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 69,
-    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 72,
-    SBK_QT3DRENDER_QMESH_IDX                                 = 71,
-    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 73,
-    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 74,
-    SBK_QT3DRENDER_QNODRAW_IDX                               = 75,
-    SBK_QT3DRENDER_QNOPICKING_IDX                            = 76,
-    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 77,
-    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 78,
-    SBK_QT3DRENDER_QPARAMETER_IDX                            = 79,
-    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 81,
-    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 82,
-    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 80,
-    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 83,
-    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 84,
-    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 85,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 88,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 89,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 87,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 86,
-    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 90,
-    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 92,
-    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 91,
-    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 93,
-    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 94,
-    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 95,
-    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 97,
-    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 96,
-    SBK_QT3DRENDER_QRENDERASPECT_SUBMISSIONTYPE_IDX          = 99,
-    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 98,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 101,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 102,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 100,
-    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 103,
-    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 104,
-    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 105,
-    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 106,
-    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 108,
-    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 107,
-    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 109,
-    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 110,
-    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 111,
-    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 112,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 114,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 113,
-    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 115,
-    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 118,
-    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 117,
-    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 116,
-    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 119,
-    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 120,
-    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 121,
-    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 123,
-    SBK_QT3DRENDER_QSETFENCE_IDX                             = 122,
-    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 124,
-    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 126,
-    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 127,
-    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 125,
-    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 130,
-    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 131,
-    SBK_QT3DRENDER_QSHADERPROGRAM_FORMAT_IDX                 = 129,
-    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 128,
-    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 132,
-    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 133,
-    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 135,
-    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 134,
-    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 136,
-    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 137,
-    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 138,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 140,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 141,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 139,
-    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 142,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 144,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 145,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 143,
-    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 146,
-    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 147,
-    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 148,
-    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 149,
-    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 150,
-    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 151,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 152,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 153,
-    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 154,
-    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 155,
-    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 156,
-    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 157,
-    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 158,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 160,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 159,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 161,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 162,
-    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 163,
-    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 164,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 166,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 165,
-    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 167,
-    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 169,
-    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 168,
-    SBK_Qt3DRender_IDX_COUNT                                 = 170
+    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 70,
+    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 73,
+    SBK_QT3DRENDER_QMESH_IDX                                 = 72,
+    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 74,
+    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 75,
+    SBK_QT3DRENDER_QNODRAW_IDX                               = 76,
+    SBK_QT3DRENDER_QNOPICKING_IDX                            = 77,
+    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 78,
+    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 79,
+    SBK_QT3DRENDER_QPARAMETER_IDX                            = 80,
+    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 82,
+    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 83,
+    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 81,
+    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 84,
+    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 85,
+    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 86,
+    SBK_QT3DRENDER_QPICKINGPROXY_IDX                         = 87,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 90,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 91,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 89,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 88,
+    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 92,
+    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 94,
+    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 93,
+    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 95,
+    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 96,
+    SBK_QT3DRENDER_QRASTERMODE_RASTERMODE_IDX                = 99,
+    SBK_QT3DRENDER_QRASTERMODE_FACEMODE_IDX                  = 98,
+    SBK_QT3DRENDER_QRASTERMODE_IDX                           = 97,
+    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 100,
+    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 102,
+    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 101,
+    SBK_QT3DRENDER_QRENDERASPECT_SUBMISSIONTYPE_IDX          = 104,
+    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 103,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 106,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 107,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 105,
+    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 108,
+    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 109,
+    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 110,
+    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 111,
+    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 113,
+    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 112,
+    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 114,
+    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 115,
+    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 116,
+    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 117,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 119,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 118,
+    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 120,
+    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 123,
+    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 122,
+    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 121,
+    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 124,
+    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 125,
+    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 126,
+    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 128,
+    SBK_QT3DRENDER_QSETFENCE_IDX                             = 127,
+    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 129,
+    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 131,
+    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 132,
+    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 130,
+    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 135,
+    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 136,
+    SBK_QT3DRENDER_QSHADERPROGRAM_FORMAT_IDX                 = 134,
+    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 133,
+    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 137,
+    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 138,
+    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 140,
+    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 139,
+    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 141,
+    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 142,
+    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 143,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 145,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 146,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 144,
+    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 147,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 149,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 150,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 148,
+    SBK_QT3DRENDER_QSUBTREEENABLER_ENABLEMENT_IDX            = 152,
+    SBK_QT3DRENDER_QSUBTREEENABLER_IDX                       = 151,
+    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 153,
+    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 154,
+    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 155,
+    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 156,
+    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 157,
+    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 158,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 159,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 160,
+    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 161,
+    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 162,
+    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 163,
+    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 164,
+    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 165,
+    SBK_QT3DRENDER_QTEXTUREDATAUPDATE_IDX                    = 166,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 168,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 167,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 169,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 170,
+    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 171,
+    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 172,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 174,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 173,
+    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 175,
+    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 177,
+    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 176,
+    SBK_Qt3DRender_IDX_COUNT                                 = 178
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_Qt3DRenderTypes;
@@ -350,20 +332,20 @@ extern SbkConverter **SbkPySide6_Qt3DRenderTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 0, // QList<Qt3DCore::QNode* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 1, // QList<Qt3DRender::QFilterKey* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 2, // QList<Qt3DRender::QParameter* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 3, // QList<Qt3DRender::QRenderPass* >
-    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 4, // const QList<QObject* > &
-    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 5, // QList<QByteArray >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 6, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 7, // QList<Qt3DRender::QRenderState* >
-    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 8, // const QList<qreal > &
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 9, // QList<Qt3DRender::QTechnique* >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 10, // QList<Qt3DCore::QComponent* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 11, // QList<Qt3DRender::QRenderTargetOutput* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 12, // const QList<Qt3DRender::QSortPolicy::SortType > &
-    SBK_QT3DRENDER_QLIST_INT_IDX                             = 13, // const QList<int > &
+    SBK_QT3DRENDER_QLIST_INT_IDX                             = 0, // QList<int >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 1, // QList<Qt3DCore::QNode* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 2, // QList<Qt3DRender::QFilterKey* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 3, // QList<Qt3DRender::QParameter* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 4, // QList<Qt3DRender::QRenderPass* >
+    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 5, // QList<QObject* >
+    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 6, // QList<QByteArray >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 7, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 8, // QList<Qt3DRender::QRenderState* >
+    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 9, // QList<qreal >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 10, // QList<Qt3DRender::QTechnique* >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 11, // QList<Qt3DCore::QComponent* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 12, // QList<Qt3DRender::QRenderTargetOutput* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 13, // QList<Qt3DRender::QSortPolicy::SortType >
     SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 14, // QList<Qt3DRender::QLayer* >
     SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 15, // QList<Qt3DRender::QAbstractTextureImage* >
     SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 16, // QList<Qt3DRender::QRayCasterHit >
@@ -421,6 +403,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QComputeCommand::RunType
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QComputeCommand >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QCullFace::CullingMode >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QCullFace >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QCULLFACE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QDepthRange >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QDEPTHRANGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QDepthTest::DepthFunction >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QDepthTest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QDEPTHTEST_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QDirectionalLight >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX]); }
@@ -465,6 +448,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickEvent >() { return r
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickLineEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKLINEEVENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickPointEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKPOINTEVENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickTriangleEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickingProxy >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKINGPROXY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickingSettings::PickMethod >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickingSettings::PickResultMode >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPickingSettings::FaceOrientationPickingMode >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX]; }
@@ -474,6 +458,9 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPointSize::SizeMode >()
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPointSize >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPOINTSIZE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPolygonOffset >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPOLYGONOFFSET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QProximityFilter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPROXIMITYFILTER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRasterMode::RasterMode >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRASTERMODE_RASTERMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRasterMode::FaceMode >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRASTERMODE_FACEMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRasterMode >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRASTERMODE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRayCaster >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRayCasterHit::HitType >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRayCasterHit >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTERHIT_IDX]); }
@@ -525,6 +512,8 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QStencilTest >() { return
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QStencilTestArguments::StencilFaceMode >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QStencilTestArguments::StencilFunction >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QStencilTestArguments >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QSubtreeEnabler::Enablement >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSUBTREEENABLER_ENABLEMENT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QSubtreeEnabler >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSUBTREEENABLER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTechnique >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTECHNIQUE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTechniqueFilter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTexture1D >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTURE1D_IDX]); }
@@ -538,6 +527,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureBuffer >() { retu
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureCubeMap >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureCubeMapArray >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREDATA_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureDataUpdate >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREDATAUPDATE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureImage::Status >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureImage >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREIMAGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureImageData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX]); }
