@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTBLUETOOTH_PYTHON_H
@@ -51,29 +15,28 @@
 
 // Bound library includes
 #include <QtBluetooth/qbluetooth.h>
-#include <QtBluetooth/qbluetoothaddress.h>
-#include <QtBluetooth/qbluetoothhostinfo.h>
 #include <QtBluetooth/qlowenergydescriptordata.h>
 #include <QtBluetooth/qbluetoothdevicediscoveryagent.h>
 #include <QtBluetooth/qlowenergyadvertisingdata.h>
 #include <QtBluetooth/qbluetoothsocket.h>
 #include <QtBluetooth/qbluetoothservicediscoveryagent.h>
 #include <QtBluetooth/qlowenergycharacteristic.h>
+#include <QtBluetooth/qlowenergycontroller.h>
+#include <QtBluetooth/qlowenergyconnectionparameters.h>
+#include <QtBluetooth/qbluetoothdeviceinfo.h>
+#include <QtBluetooth/qbluetoothlocaldevice.h>
+#include <QtBluetooth/qlowenergydescriptor.h>
+#include <QtBluetooth/qbluetoothaddress.h>
+#include <QtBluetooth/qbluetoothhostinfo.h>
 #include <QtBluetooth/qlowenergycharacteristicdata.h>
 #include <QtBluetooth/qlowenergyservicedata.h>
 #include <QtBluetooth/qlowenergyservice.h>
 #include <QtBluetooth/qbluetoothserver.h>
-#include <QtBluetooth/qlowenergycontroller.h>
-#include <QtBluetooth/qlowenergyconnectionparameters.h>
 #include <QtBluetooth/qbluetoothserviceinfo.h>
-#include <QtBluetooth/qbluetoothdeviceinfo.h>
-#include <QtBluetooth/qbluetoothlocaldevice.h>
 #include <QtBluetooth/qbluetoothuuid.h>
 #include <QtBluetooth/qlowenergyadvertisingparameters.h>
-#include <QtBluetooth/qlowenergydescriptor.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -88,6 +51,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -99,6 +67,7 @@ enum : int {
     SBK_QBLUETOOTHADDRESS_IDX                                = 3,
     SBK_QBLUETOOTHDEVICEDISCOVERYAGENT_ERROR_IDX             = 6,
     SBK_QBLUETOOTHDEVICEDISCOVERYAGENT_DISCOVERYMETHOD_IDX   = 5,
+    SBK_QFLAGS_QBLUETOOTHDEVICEDISCOVERYAGENT_DISCOVERYMETHOD_IDX = 47,
     SBK_QBLUETOOTHDEVICEDISCOVERYAGENT_IDX                   = 4,
     SBK_QBLUETOOTHDEVICEINFO_MAJORDEVICECLASS_IDX            = 10,
     SBK_QBLUETOOTHDEVICEINFO_MINORMISCELLANEOUSCLASS_IDX     = 15,
@@ -112,11 +81,11 @@ enum : int {
     SBK_QBLUETOOTHDEVICEINFO_MINORTOYCLASS_IDX               = 19,
     SBK_QBLUETOOTHDEVICEINFO_MINORHEALTHCLASS_IDX            = 13,
     SBK_QBLUETOOTHDEVICEINFO_SERVICECLASS_IDX                = 21,
-    SBK_QFLAGS_QBLUETOOTHDEVICEINFO_SERVICECLASS_IDX         = 49,
+    SBK_QFLAGS_QBLUETOOTHDEVICEINFO_SERVICECLASS_IDX         = 50,
     SBK_QBLUETOOTHDEVICEINFO_FIELD_IDX                       = 9,
-    SBK_QFLAGS_QBLUETOOTHDEVICEINFO_FIELD_IDX                = 48,
+    SBK_QFLAGS_QBLUETOOTHDEVICEINFO_FIELD_IDX                = 49,
     SBK_QBLUETOOTHDEVICEINFO_CORECONFIGURATION_IDX           = 8,
-    SBK_QFLAGS_QBLUETOOTHDEVICEINFO_CORECONFIGURATION_IDX    = 47,
+    SBK_QFLAGS_QBLUETOOTHDEVICEINFO_CORECONFIGURATION_IDX    = 48,
     SBK_QBLUETOOTHDEVICEINFO_IDX                             = 7,
     SBK_QBLUETOOTHHOSTINFO_IDX                               = 22,
     SBK_QBLUETOOTHLOCALDEVICE_PAIRING_IDX                    = 26,
@@ -141,34 +110,34 @@ enum : int {
     SBK_QBLUETOOTHUUID_CHARACTERISTICTYPE_IDX                = 41,
     SBK_QBLUETOOTHUUID_DESCRIPTORTYPE_IDX                    = 42,
     SBK_QBLUETOOTHUUID_IDX                                   = 40,
-    SBK_QLOWENERGYADVERTISINGDATA_DISCOVERABILITY_IDX        = 53,
-    SBK_QLOWENERGYADVERTISINGDATA_IDX                        = 52,
-    SBK_QLOWENERGYADVERTISINGPARAMETERS_MODE_IDX             = 57,
-    SBK_QLOWENERGYADVERTISINGPARAMETERS_FILTERPOLICY_IDX     = 56,
-    SBK_QLOWENERGYADVERTISINGPARAMETERS_IDX                  = 54,
-    SBK_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX      = 55,
-    SBK_QLOWENERGYCHARACTERISTIC_PROPERTYTYPE_IDX            = 59,
-    SBK_QFLAGS_QLOWENERGYCHARACTERISTIC_PROPERTYTYPE_IDX     = 50,
-    SBK_QLOWENERGYCHARACTERISTIC_IDX                         = 58,
-    SBK_QLOWENERGYCHARACTERISTICDATA_IDX                     = 60,
-    SBK_QLOWENERGYCONNECTIONPARAMETERS_IDX                   = 61,
-    SBK_QLOWENERGYCONTROLLER_ERROR_IDX                       = 64,
-    SBK_QLOWENERGYCONTROLLER_CONTROLLERSTATE_IDX             = 63,
-    SBK_QLOWENERGYCONTROLLER_REMOTEADDRESSTYPE_IDX           = 65,
-    SBK_QLOWENERGYCONTROLLER_ROLE_IDX                        = 66,
-    SBK_QLOWENERGYCONTROLLER_IDX                             = 62,
-    SBK_QLOWENERGYDESCRIPTOR_IDX                             = 67,
-    SBK_QLOWENERGYDESCRIPTORDATA_IDX                         = 68,
-    SBK_QLOWENERGYSERVICE_SERVICETYPE_IDX                    = 73,
-    SBK_QFLAGS_QLOWENERGYSERVICE_SERVICETYPE_IDX             = 51,
-    SBK_QLOWENERGYSERVICE_SERVICEERROR_IDX                   = 71,
-    SBK_QLOWENERGYSERVICE_SERVICESTATE_IDX                   = 72,
-    SBK_QLOWENERGYSERVICE_DISCOVERYMODE_IDX                  = 70,
-    SBK_QLOWENERGYSERVICE_WRITEMODE_IDX                      = 74,
-    SBK_QLOWENERGYSERVICE_IDX                                = 69,
-    SBK_QLOWENERGYSERVICEDATA_SERVICETYPE_IDX                = 76,
-    SBK_QLOWENERGYSERVICEDATA_IDX                            = 75,
-    SBK_QtBluetooth_IDX_COUNT                                = 77
+    SBK_QLOWENERGYADVERTISINGDATA_DISCOVERABILITY_IDX        = 54,
+    SBK_QLOWENERGYADVERTISINGDATA_IDX                        = 53,
+    SBK_QLOWENERGYADVERTISINGPARAMETERS_MODE_IDX             = 58,
+    SBK_QLOWENERGYADVERTISINGPARAMETERS_FILTERPOLICY_IDX     = 57,
+    SBK_QLOWENERGYADVERTISINGPARAMETERS_IDX                  = 55,
+    SBK_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX      = 56,
+    SBK_QLOWENERGYCHARACTERISTIC_PROPERTYTYPE_IDX            = 60,
+    SBK_QFLAGS_QLOWENERGYCHARACTERISTIC_PROPERTYTYPE_IDX     = 51,
+    SBK_QLOWENERGYCHARACTERISTIC_IDX                         = 59,
+    SBK_QLOWENERGYCHARACTERISTICDATA_IDX                     = 61,
+    SBK_QLOWENERGYCONNECTIONPARAMETERS_IDX                   = 62,
+    SBK_QLOWENERGYCONTROLLER_ERROR_IDX                       = 65,
+    SBK_QLOWENERGYCONTROLLER_CONTROLLERSTATE_IDX             = 64,
+    SBK_QLOWENERGYCONTROLLER_REMOTEADDRESSTYPE_IDX           = 66,
+    SBK_QLOWENERGYCONTROLLER_ROLE_IDX                        = 67,
+    SBK_QLOWENERGYCONTROLLER_IDX                             = 63,
+    SBK_QLOWENERGYDESCRIPTOR_IDX                             = 68,
+    SBK_QLOWENERGYDESCRIPTORDATA_IDX                         = 69,
+    SBK_QLOWENERGYSERVICE_SERVICETYPE_IDX                    = 74,
+    SBK_QFLAGS_QLOWENERGYSERVICE_SERVICETYPE_IDX             = 52,
+    SBK_QLOWENERGYSERVICE_SERVICEERROR_IDX                   = 72,
+    SBK_QLOWENERGYSERVICE_SERVICESTATE_IDX                   = 73,
+    SBK_QLOWENERGYSERVICE_DISCOVERYMODE_IDX                  = 71,
+    SBK_QLOWENERGYSERVICE_WRITEMODE_IDX                      = 75,
+    SBK_QLOWENERGYSERVICE_IDX                                = 70,
+    SBK_QLOWENERGYSERVICEDATA_SERVICETYPE_IDX                = 77,
+    SBK_QLOWENERGYSERVICEDATA_IDX                            = 76,
+    SBK_QtBluetooth_IDX_COUNT                                = 78
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtBluetoothTypes;
@@ -181,25 +150,27 @@ extern SbkConverter **SbkPySide6_QtBluetoothTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTICDATA_IDX   = 0, // QList<QLowEnergyCharacteristicData >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYSERVICEPTR_IDX           = 1, // QList<QLowEnergyService* >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTIC_IDX       = 2, // QList<QLowEnergyCharacteristic >
-    SBK_QTBLUETOOTH_QLIST_QOBJECTPTR_IDX                     = 3, // QList<QObject* >
-    SBK_QTBLUETOOTH_QLIST_QBYTEARRAY_IDX                     = 4, // QList<QByteArray >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHUUID_IDX                 = 5, // QList<QBluetoothUuid >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTORDATA_IDX       = 6, // QList<QLowEnergyDescriptorData >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTOR_IDX           = 7, // QList<QLowEnergyDescriptor >
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX = 8, // QList<QLowEnergyAdvertisingParameters::AddressInfo >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHSERVICEINFO_IDX          = 9, // QList<QBluetoothServiceInfo >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHHOSTINFO_IDX             = 10, // QList<QBluetoothHostInfo >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHADDRESS_IDX              = 11, // QList<QBluetoothAddress >
-    SBK_QTBLUETOOTH_QMULTIHASH_QUINT16_QBYTEARRAY_IDX        = 12, // QMultiHash<quint16,QByteArray >
-    SBK_QTBLUETOOTH_QLIST_QUINT16_IDX                        = 13, // QList<quint16 >
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHDEVICEINFO_IDX           = 14, // QList<QBluetoothDeviceInfo >
-    SBK_QTBLUETOOTH_QLIST_QVARIANT_IDX                       = 15, // QList<QVariant >
-    SBK_QTBLUETOOTH_QLIST_QSTRING_IDX                        = 16, // QList<QString >
-    SBK_QTBLUETOOTH_QMAP_QSTRING_QVARIANT_IDX                = 17, // QMap<QString,QVariant >
-    SBK_QtBluetooth_CONVERTERS_IDX_COUNT                     = 18
+    SBK_QTBLUETOOTH_QLIST_INT_IDX                            = 0, // QList<int >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTICDATA_IDX   = 1, // QList<QLowEnergyCharacteristicData >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYSERVICEPTR_IDX           = 2, // QList<QLowEnergyService* >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTIC_IDX       = 3, // QList<QLowEnergyCharacteristic >
+    SBK_QTBLUETOOTH_QLIST_QOBJECTPTR_IDX                     = 4, // QList<QObject* >
+    SBK_QTBLUETOOTH_QLIST_QBYTEARRAY_IDX                     = 5, // QList<QByteArray >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHUUID_IDX                 = 6, // QList<QBluetoothUuid >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTORDATA_IDX       = 7, // QList<QLowEnergyDescriptorData >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTOR_IDX           = 8, // QList<QLowEnergyDescriptor >
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX = 9, // QList<QLowEnergyAdvertisingParameters::AddressInfo >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHSERVICEINFO_IDX          = 10, // QList<QBluetoothServiceInfo >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHHOSTINFO_IDX             = 11, // QList<QBluetoothHostInfo >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHADDRESS_IDX              = 12, // QList<QBluetoothAddress >
+    SBK_QTBLUETOOTH_QMULTIHASH_QUINT16_QBYTEARRAY_IDX        = 13, // QMultiHash<quint16,QByteArray >
+    SBK_QTBLUETOOTH_QLIST_QUINT16_IDX                        = 14, // QList<quint16 >
+    SBK_QTBLUETOOTH_QMULTIHASH_QBLUETOOTHUUID_QBYTEARRAY_IDX = 15, // QMultiHash<QBluetoothUuid,QByteArray >
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHDEVICEINFO_IDX           = 16, // QList<QBluetoothDeviceInfo >
+    SBK_QTBLUETOOTH_QLIST_QVARIANT_IDX                       = 17, // QList<QVariant >
+    SBK_QTBLUETOOTH_QLIST_QSTRING_IDX                        = 18, // QList<QString >
+    SBK_QTBLUETOOTH_QMAP_QSTRING_QVARIANT_IDX                = 19, // QMap<QString,QVariant >
+    SBK_QtBluetooth_CONVERTERS_IDX_COUNT                     = 20
 };
 // Macros for type check
 
@@ -216,6 +187,7 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QBluetooth::AttAccessConstrain
 template<> inline PyTypeObject *SbkType< ::QBluetoothAddress >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtBluetoothTypes[SBK_QBLUETOOTHADDRESS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QBluetoothDeviceDiscoveryAgent::Error >() { return SbkPySide6_QtBluetoothTypes[SBK_QBLUETOOTHDEVICEDISCOVERYAGENT_ERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QBluetoothDeviceDiscoveryAgent::DiscoveryMethod >() { return SbkPySide6_QtBluetoothTypes[SBK_QBLUETOOTHDEVICEDISCOVERYAGENT_DISCOVERYMETHOD_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QBluetoothDeviceDiscoveryAgent::DiscoveryMethod> >() { return SbkPySide6_QtBluetoothTypes[SBK_QFLAGS_QBLUETOOTHDEVICEDISCOVERYAGENT_DISCOVERYMETHOD_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QBluetoothDeviceDiscoveryAgent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtBluetoothTypes[SBK_QBLUETOOTHDEVICEDISCOVERYAGENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QBluetoothDeviceInfo::MajorDeviceClass >() { return SbkPySide6_QtBluetoothTypes[SBK_QBLUETOOTHDEVICEINFO_MAJORDEVICECLASS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QBluetoothDeviceInfo::MinorMiscellaneousClass >() { return SbkPySide6_QtBluetoothTypes[SBK_QBLUETOOTHDEVICEINFO_MINORMISCELLANEOUSCLASS_IDX]; }
