@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTQML_PYTHON_H
@@ -49,26 +13,29 @@
 // Module Includes
 #include <pyside6_qtcore_python.h>
 #include <pyside6_qtnetwork_python.h>
-#include <pyside6_qtgui_python.h>
 
 // Bound library includes
 #include <QtQml/qjsvalueiterator.h>
-#include <QtQml/qqmlcomponent.h>
 #include <QtQml/qqmlextensionplugin.h>
 #include <QtQml/qqmlpropertymap.h>
-#include <QtQml/qjsvalue.h>
 #include <QtQml/qqmlnetworkaccessmanagerfactory.h>
+#include <QtQml/qqmlfileselector.h>
+#include <qpyqmlpropertyvaluesource.h>
+#include <QtQml/qjsmanagedvalue.h>
+#include <QtQml/qqmldebug.h>
+#include <QtQml/qqml.h>
+#include <qpyqmlparserstatus.h>
+#include <QtQml/qqmlparserstatus.h>
+#include <QtQml/qqmlcomponent.h>
+#include <QtQml/qjsvalue.h>
+#include <QtQml/qjsprimitivevalue.h>
 #include <QtQml/qqmlapplicationengine.h>
 #include <QtQml/qqmlcontext.h>
 #include <QtQml/qqmlfile.h>
 #include <QtQml/qqmlexpression.h>
-#include <QtQml/qqmlfileselector.h>
-#include <QtQml/qqmldebug.h>
 #include <QtQml/qqmlextensioninterface.h>
-#include <QtQml/qqml.h>
 #include <QtQml/qqmlincubator.h>
 #include <QtQml/qqmlpropertyvaluesource.h>
-#include <QtQml/qqmlparserstatus.h>
 #include <QtQml/qqmlabstracturlinterceptor.h>
 #include <QtQml/qjsengine.h>
 #include <QtQml/qqmlengine.h>
@@ -77,21 +44,26 @@
 #include <QtQml/qqmlscriptstring.h>
 #include <QtQml/qqmlproperty.h>
 // Conversion Includes - Primitive Types
-#include <qabstractitemmodel.h>
+#include <QAnyStringView>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Begin code injection
 // Volatile Bool Ptr type definition for QQmlIncubationController::incubateWhile(std::atomic<bool> *, int)
@@ -111,47 +83,56 @@ enum : int {
     SBK_QJSENGINE_EXTENSION_IDX                              = 3,
     SBK_QFLAGS_QJSENGINE_EXTENSION_IDX                       = 0,
     SBK_QJSENGINE_IDX                                        = 2,
-    SBK_QJSVALUE_SPECIALVALUE_IDX                            = 7,
-    SBK_QJSVALUE_ERRORTYPE_IDX                               = 6,
-    SBK_QJSVALUE_IDX                                         = 5,
-    SBK_QJSVALUEITERATOR_IDX                                 = 8,
-    SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX              = 10,
-    SBK_QQMLABSTRACTURLINTERCEPTOR_IDX                       = 9,
-    SBK_QQMLAPPLICATIONENGINE_IDX                            = 11,
-    SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX                    = 13,
-    SBK_QQMLCOMPONENT_STATUS_IDX                             = 14,
-    SBK_QQMLCOMPONENT_IDX                                    = 12,
-    SBK_QQMLCONTEXT_IDX                                      = 15,
-    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 17,
-    SBK_QQMLDEBUGGINGENABLER_IDX                             = 16,
-    SBK_QQMLENGINE_IDX                                       = 18,
-    SBK_QQMLERROR_IDX                                        = 19,
-    SBK_QQMLEXPRESSION_IDX                                   = 20,
-    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 21,
-    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 22,
-    SBK_QQMLFILE_STATUS_IDX                                  = 24,
-    SBK_QQMLFILE_IDX                                         = 23,
-    SBK_QQMLFILESELECTOR_IDX                                 = 25,
-    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 28,
-    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 27,
+    SBK_QJSMANAGEDVALUE_TYPE_IDX                             = 6,
+    SBK_QJSMANAGEDVALUE_IDX                                  = 5,
+    SBK_QJSPRIMITIVEVALUE_TYPE_IDX                           = 8,
+    SBK_QJSPRIMITIVEVALUE_IDX                                = 7,
+    SBK_QJSVALUE_SPECIALVALUE_IDX                            = 12,
+    SBK_QJSVALUE_ERRORTYPE_IDX                               = 10,
+    SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX                = 11,
+    SBK_QJSVALUE_IDX                                         = 9,
+    SBK_QJSVALUEITERATOR_IDX                                 = 13,
+    SBK_QPYQMLPARSERSTATUS_IDX                               = 15,
+    SBK_QPYQMLPROPERTYVALUESOURCE_IDX                        = 16,
+    SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX              = 18,
+    SBK_QQMLABSTRACTURLINTERCEPTOR_IDX                       = 17,
+    SBK_QQMLAPPLICATIONENGINE_IDX                            = 19,
+    SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX                    = 21,
+    SBK_QQMLCOMPONENT_STATUS_IDX                             = 22,
+    SBK_QQMLCOMPONENT_IDX                                    = 20,
+    SBK_QQMLCONTEXT_IDX                                      = 23,
+    SBK_QQMLCONTEXT_PROPERTYPAIR_IDX                         = 24,
+    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 26,
+    SBK_QQMLDEBUGGINGENABLER_IDX                             = 25,
+    SBK_QQMLENGINE_IDX                                       = 27,
+    SBK_QQMLERROR_IDX                                        = 28,
+    SBK_QQMLEXPRESSION_IDX                                   = 29,
+    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 30,
+    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 31,
+    SBK_QQMLFILE_STATUS_IDX                                  = 33,
+    SBK_QQMLFILE_IDX                                         = 32,
+    SBK_QQMLFILESELECTOR_IDX                                 = 34,
+    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 37,
+    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 36,
     SBK_QFLAGS_QQMLIMAGEPROVIDERBASE_FLAG_IDX                = 1,
-    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 26,
-    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 29,
-    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 31,
-    SBK_QQMLINCUBATOR_STATUS_IDX                             = 32,
-    SBK_QQMLINCUBATOR_IDX                                    = 30,
-    SBK_QQMLLISTREFERENCE_IDX                                = 33,
-    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 35,
-    SBK_QQMLPARSERSTATUS_IDX                                 = 36,
-    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 38,
-    SBK_QQMLPROPERTY_TYPE_IDX                                = 39,
-    SBK_QQMLPROPERTY_IDX                                     = 37,
-    SBK_QQMLPROPERTYMAP_IDX                                  = 40,
-    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 41,
-    SBK_QQMLSCRIPTSTRING_IDX                                 = 42,
-    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 43,
-    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 34,
-    SBK_QtQml_IDX_COUNT                                      = 45
+    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 35,
+    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 38,
+    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 40,
+    SBK_QQMLINCUBATOR_STATUS_IDX                             = 41,
+    SBK_QQMLINCUBATOR_IDX                                    = 39,
+    SBK_QQMLLISTREFERENCE_IDX                                = 42,
+    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 44,
+    SBK_QQMLPARSERSTATUS_IDX                                 = 45,
+    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 47,
+    SBK_QQMLPROPERTY_TYPE_IDX                                = 48,
+    SBK_QQMLPROPERTY_IDX                                     = 46,
+    SBK_QQMLPROPERTYMAP_IDX                                  = 49,
+    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 50,
+    SBK_QQMLSCRIPTSTRING_IDX                                 = 51,
+    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 52,
+    SBK_QML_HAS_ATTACHED_PROPERTIES_IDX                      = 14,
+    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 43,
+    SBK_QtQml_IDX_COUNT                                      = 54
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtQmlTypes;
@@ -164,15 +145,18 @@ extern SbkConverter **SbkPySide6_QtQmlTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTQML_QLIST_QQMLERROR_IDX                            = 0, // QList<QQmlError >
-    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 1, // const QMap<QString,QVariant > &
-    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 2, // const QHash<QString,QVariant > &
-    SBK_QTQML_QLIST_QJSVALUE_IDX                             = 3, // const QList<QJSValue > &
-    SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 4, // const QList<QObject* > &
-    SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 5, // QList<QByteArray >
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 6, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 7, // QList<QString >
-    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 8
+    SBK_QTQML_QLIST_INT_IDX                                  = 0, // QList<int >
+    SBK_QTQML_QLIST_QQMLERROR_IDX                            = 1, // QList<QQmlError >
+    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 2, // QMap<QString,QVariant >
+    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 3, // QHash<QString,QVariant >
+    SBK_QTQML_QLIST_QJSVALUE_IDX                             = 4, // QList<QJSValue >
+    SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 5, // QList<QObject* >
+    SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 6, // QList<QByteArray >
+    SBK_QTQML_QLIST_QQMLCONTEXT_PROPERTYPAIR_IDX             = 7, // QList<QQmlContext::PropertyPair >
+    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 8, // QList<QQmlAbstractUrlInterceptor* >
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 9, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 10, // QList<QString >
+    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 11
 };
 // Macros for type check
 
@@ -187,10 +171,17 @@ template<> inline PyTypeObject *SbkType< ::QJSEngine::ObjectOwnership >() { retu
 template<> inline PyTypeObject *SbkType< ::QJSEngine::Extension >() { return SbkPySide6_QtQmlTypes[SBK_QJSENGINE_EXTENSION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QJSEngine::Extension> >() { return SbkPySide6_QtQmlTypes[SBK_QFLAGS_QJSENGINE_EXTENSION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSENGINE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QJSManagedValue::Type >() { return SbkPySide6_QtQmlTypes[SBK_QJSMANAGEDVALUE_TYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSManagedValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSMANAGEDVALUE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QJSPrimitiveValue::Type >() { return SbkPySide6_QtQmlTypes[SBK_QJSPRIMITIVEVALUE_TYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSPrimitiveValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSPRIMITIVEVALUE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QJSValue::SpecialValue >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_SPECIALVALUE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSValue::ErrorType >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_ERRORTYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSValue::ObjectConversionBehavior >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSVALUE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QJSValueIterator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSVALUEITERATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPyQmlParserStatus >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QPYQMLPARSERSTATUS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPyQmlPropertyValueSource >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QPYQMLPROPERTYVALUESOURCE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlAbstractUrlInterceptor::DataType >() { return SbkPySide6_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQmlAbstractUrlInterceptor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLABSTRACTURLINTERCEPTOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlApplicationEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLAPPLICATIONENGINE_IDX]); }
@@ -198,6 +189,7 @@ template<> inline PyTypeObject *SbkType< ::QQmlComponent::CompilationMode >() {
 template<> inline PyTypeObject *SbkType< ::QQmlComponent::Status >() { return SbkPySide6_QtQmlTypes[SBK_QQMLCOMPONENT_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQmlComponent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLCOMPONENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlContext >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLCONTEXT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQmlContext::PropertyPair >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLCONTEXT_PROPERTYPAIR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlDebuggingEnabler::StartMode >() { return SbkPySide6_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQmlDebuggingEnabler >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLDEBUGGINGENABLER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QQMLENGINE_IDX]); }
