@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTSQL_PYTHON_H
@@ -53,34 +17,39 @@
 
 // Bound library includes
 #include <QtSql/qsqlindex.h>
+#include <QtSql/qsqlerror.h>
+#include <QtSql/qsqlquerymodel.h>
+#include <QtSql/qsqlrelationaldelegate.h>
 #include <QtSql/qsqlrelationaltablemodel.h>
+#include <QtSql/qsqldriver.h>
+#include <QtSql/qsqlquery.h>
 #include <QtSql/qsqlresult.h>
 #include <QtSql/qtsqlglobal.h>
-#include <QtSql/qsqldatabase.h>
-#include <QtSql/qsqldriver.h>
 #include <QtSql/qsqltablemodel.h>
-#include <QtSql/qsqlerror.h>
 #include <QtSql/qsqlfield.h>
-#include <QtSql/qsqlquerymodel.h>
-#include <QtSql/qsqlquery.h>
 #include <QtSql/qsqlrecord.h>
-#include <QtSql/qsqlrelationaldelegate.h>
+#include <QtSql/qsqldatabase.h>
 // Conversion Includes - Primitive Types
-#include <qabstractitemmodel.h>
+#include <QAnyStringView>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -112,10 +81,11 @@ enum : int {
     SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX                = 26,
     SBK_QSQLRELATIONALTABLEMODEL_IDX                         = 25,
     SBK_QSQLRESULT_BINDINGSYNTAX_IDX                         = 28,
+    SBK_QSQLRESULT_VIRTUALHOOKOPERATION_IDX                  = 29,
     SBK_QSQLRESULT_IDX                                       = 27,
-    SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                      = 30,
-    SBK_QSQLTABLEMODEL_IDX                                   = 29,
-    SBK_QtSql_IDX_COUNT                                      = 31
+    SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                      = 31,
+    SBK_QSQLTABLEMODEL_IDX                                   = 30,
+    SBK_QtSql_IDX_COUNT                                      = 32
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtSqlTypes;
@@ -128,15 +98,16 @@ extern SbkConverter **SbkPySide6_QtSqlTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSQL_QLIST_QVARIANT_IDX                             = 0, // QList<QVariant > &
-    SBK_QTSQL_QLIST_INT_IDX                                  = 1, // QList<int >
-    SBK_QTSQL_QLIST_QOBJECTPTR_IDX                           = 2, // const QList<QObject* > &
+    SBK_QTSQL_QLIST_INT_IDX                                  = 0, // QList<int >
+    SBK_QTSQL_QLIST_QVARIANT_IDX                             = 1, // QList<QVariant >
+    SBK_QTSQL_QLIST_QOBJECTPTR_IDX                           = 2, // QList<QObject* >
     SBK_QTSQL_QLIST_QBYTEARRAY_IDX                           = 3, // QList<QByteArray >
     SBK_QTSQL_QMAP_INT_QVARIANT_IDX                          = 4, // QMap<int,QVariant >
-    SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                       = 5, // QHash<int,QByteArray >
-    SBK_QTSQL_QLIST_QSTRING_IDX                              = 6, // QList<QString >
-    SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                      = 7, // QMap<QString,QVariant >
-    SBK_QtSql_CONVERTERS_IDX_COUNT                           = 8
+    SBK_QTSQL_QLIST_QMODELINDEX_IDX                          = 5, // QList<QModelIndex >
+    SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                       = 6, // QHash<int,QByteArray >
+    SBK_QTSQL_QLIST_QSTRING_IDX                              = 7, // QList<QString >
+    SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                      = 8, // QMap<QString,QVariant >
+    SBK_QtSql_CONVERTERS_IDX_COUNT                           = 9
 };
 // Macros for type check
 
@@ -173,6 +144,7 @@ template<> inline PyTypeObject *SbkType< ::QSqlRelationalDelegate >() { return r
 template<> inline PyTypeObject *SbkType< ::QSqlRelationalTableModel::JoinMode >() { return SbkPySide6_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlRelationalTableModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSqlResult::BindingSyntax >() { return SbkPySide6_QtSqlTypes[SBK_QSQLRESULT_BINDINGSYNTAX_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSqlResult::VirtualHookOperation >() { return SbkPySide6_QtSqlTypes[SBK_QSQLRESULT_VIRTUALHOOKOPERATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlResult >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSqlTypes[SBK_QSQLRESULT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSqlTableModel::EditStrategy >() { return SbkPySide6_QtSqlTypes[SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlTableModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSqlTypes[SBK_QSQLTABLEMODEL_IDX]); }
